MethodChannelDeviceAppsPlus class

An implementation of DeviceAppsPlusPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkMultiple(List<String> packageNames) → Future<Map<String, bool>>
override
getPlatformVersion() → Future<String?>
override
isAppInstalled(String packageName) → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openApp(String packageName) → Future<bool>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited